<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dist?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// D
	'dist_description' => 'Default template set in SPIP 3.',
	'dist_slogan' => 'Default template set in SPIP 3',
];
